pyxmpp.sasl.core.Reply

Package pyxmpp :: Package sasl :: Module core :: Class Reply |
[hide private]

# Class Reply

source code

Known Subclasses:
  - Challenge
  - , Failure
  - , Response
  - , Success

Base class for SASL authentication reply objects.

Instance Methods | [hide private]
__init__(self, data=`'````'`) Initialize the Reply object. | source code
`str` |
base64(self) Base64-encode the data contained in the reply. | source code

Instance Variables | [hide private]
`str` | data optional reply data.

Method Details | [hide private]

### __init__(self, data=`'````'`) (Constructor) | source code
Initialize the Reply object. Parameters: `data` (`str`) - optional reply data.

### base64(self) | source code
Base64-encode the data contained in the reply. Returns: `str` base64-encoded data.